<?php
	/*
		Name:		 Calibre PHP webserver
		License:	 GPL v3
		Copyright:	 2010, Charles Haley
	                 http://charles.haleys.org
	*/

	require_once 'module.php';
	require_once 'utilities.php';
	require_once 'config.php';
	require_once 'mimetypes.php';

	/*
	 * The handler that delivers a book format (epub, mobi, etc.)
	 */
	class DoBookFormat extends Module {

		function check_arguments($db) {
			/*
			 *  None of these error messages will go anywhere, because the
			 *  browser is expecting a book, not an html page.
			 */
			if (!isset($_REQUEST['b']))
				return "Missing book path argument 'b' in query string";
			$path = str_replace('\\', '/', $_REQUEST['b']);
			$p = $db->libpath . '/' . $path;
			// make sure we aren't being asked to browse the file system.
			if (strpos($p, '../') !== false)
				return "Invalid path -- contains ../";
			if (!($path = case_insensitive_path($db->libpath, $_REQUEST['b'])))
				return "no such book $path";
			return false;
		}

		function do_work($smarty, $db) {
			global $config, $mimetypes;

			if (!($path = case_insensitive_path($db->libpath, $_REQUEST['b']))) {
				// This shouldn't happen, because the test was made above
				return "no such book $path";
			}
			$pathinfo = pathinfo($path);

			$mt = NULL;
			// get the mimetype of the format to be downloaded
			if (isset($pathinfo['extension'])) {
				$ext = strtolower($pathinfo['extension']);
				if (isset($mimetypes[$ext]))
					$mt = $mimetypes[$ext];
			}
			if (!$mt) {
				// mimetype unknown. Ask PHP for one.
				$finfo = finfo_open(FILEINFO_MIME_TYPE);
				$mt = finfo_file($finfo, $path);
			}
			header ('Content-type: ' . $mt);
			readfile($path);
		}

		function template() {
			return NULL;
		}
	}

	$mod = new DoBookFormat();
?>